import Box from '@mui/material/Box';
import { NsImage, NsTypography } from '../';
import { styled } from '@nuskin/foundation-theme';

type NsPostProps = {
    text: string;
    body: string;
    backgroundImageUrl: string;
    backgroundImageAlt: string;
    className?: string;
};

const CardContainer = styled(Box)(() => {
    return {
        backgroundClip: 'border-box',
        display: 'flex',
        flexDirection: 'column' as 'column',
        wordWrap: 'break-word' as 'break-word',
        position: 'relative',
        overflow: 'hidden',
        height: 'auto',
        maxWidth: '165px',
        backgroundColor: '#fff',
        '.content': {
            paddingTop: '10px',
            display: 'flex',
            flexDirection: 'column',
            minHeight: '80px',
            justifyContent: 'space-between',
            padding: '20px',
        },
        '.body-title': {
            marginBottom: '5px',
            display: '-webkit-box',
            '-webkit-box-orient': 'vertical',
            '-webkit-line-clamp': '3',
            overflow: 'hidden',
            textOverflow: 'ellipsis',
            fontSize: '18px',
            fontWeight: 600,
            lineHeight: '22px',
            fontFamily: 'Inter',
        },
        '.body-text': {
            color: '#8C8C8C',
            margin: '0px',
            fontSize: '16px',
            fontWeight: 600,
            lineHeight: '16px',
            fontFamily: 'Inter',
        },
    };
});

const NsPost = ({ text, body, backgroundImageUrl, backgroundImageAlt, className }: NsPostProps) => {
    return (
        <CardContainer className={className} data-testid="post-card">
            <div className="image">
                <NsImage height="auto" width="100%" alt={backgroundImageAlt} src={backgroundImageUrl} />
            </div>
            <div className="content">
                <NsTypography weight="normal" className="body-title" variant="h5">
                    {text}
                </NsTypography>
                <NsTypography className="body-text" variant="body-l">
                    {body}
                </NsTypography>
            </div>
        </CardContainer>
    );
};
export default NsPost;
